===================
Save Load Object
===================

A simple set of functions allows to save any python object as a pickle file. Two functions save_object(dump) and load_from_file (load) provide seamless and convenient interface to dump and load any object.

Start by importing UBCS LCP auxiliary package library.

first you can install the auxiliary library

.. code-block:: shell

  pip3 install ubcs_auxiliary

you may need to upgrade the library if it was installed before

.. code-block:: shell

  pip3 install --upgrade ubcs_auxiliary

#.. automodule:: ubcs_auxiliary.save_load_object
#  :members:
